@@ -11,7 +11,7 @@ SQL_KEYWORDS = {"order", "group", "by", "as", "from", "select", "on", "with"}
 
 class Field(MetricsLayerBase, SQLReplacement):
     def __init__(self, definition: dict = {}, view=None) -> None:
-        self.defaults = {"type": "string", "primary_key": "no"}
+        self.defaults = {"type": "string", "primary_key": "no", "datatype": "timestamp"}
         self.default_intervals = ["second", "minute", "hour", "day", "week", "month", "quarter", "year"]
 
         # Always lowercase names and make exception for the None case in the
@@ -50,14 +50,6 @@ class Field(MetricsLayerBase, SQLReplacement):
         if "sql" not in definition and "case" in definition:
             definition["sql"] = self._translate_looker_case_to_sql(definition["case"])
 
-        if "sql" in definition and "filters" in definition:
-            definition["sql"] = Filter.translate_looker_filters_to_sql(
-                definition["sql"], definition["filters"]
-            )
-
-        if "sql" in definition and definition.get("type") == "tier":
-            definition["sql"] = self._translate_looker_tier_to_sql(definition["sql"], definition["tiers"])
-
         if (
             "sql" not in definition
             and definition.get("field_type") == "measure"
@@ -68,6 +60,20 @@ class Field(MetricsLayerBase, SQLReplacement):
             else:
                 definition["sql"] = "*"
 
+        if "sql" in definition and "filters" in definition:
+            if definition["sql"] == "*":
+                raise ValueError(
+                    "To apply filters to a count measure you must have the primary_key specified "
+                    "for the view. You can do this by adding the tag 'primary_key: yes' to the "
+                    "necessary dimension"
+                )
+            definition["sql"] = Filter.translate_looker_filters_to_sql(
+                definition["sql"], definition["filters"]
+            )
+
+        if "sql" in definition and definition.get("type") == "tier":
+            definition["sql"] = self._translate_looker_tier_to_sql(definition["sql"], definition["tiers"])
+
         if "sql" in definition:
             definition["sql"] = self._clean_sql_for_case(definition["sql"])
         return definition.get("sql")
@@ -83,6 +89,14 @@ class Field(MetricsLayerBase, SQLReplacement):
             return label
         return self.alias().replace("_", " ").title()
 
+    @property
+    def datatype(self):
+        if "datatype" in self._definition:
+            return self._definition["datatype"]
+        elif self._definition["field_type"] == "dimension_group":
+            return self.defaults["datatype"]
+        return
+
     @property
     def drill_fields(self):
         drill_fields = self._definition.get("drill_fields")
@@ -271,7 +285,7 @@ class Field(MetricsLayerBase, SQLReplacement):
                         to_replace = self.view.name
                 else:
                     field = self.get_field_with_view_info(field_name)
-                    to_replace = field.aggregate_sql_query(query_type, functional_pk, alias_only=alias_only)
+                    to_replace = field.sql_query(query_type, functional_pk, alias_only=alias_only)
                 replaced = replaced.replace(proper_to_replace, to_replace)
         else:
             raise ValueError(f"handle case for sql: {sql}")
@@ -338,11 +352,13 @@ class Field(MetricsLayerBase, SQLReplacement):
         if view_name and view_name != self.view.name:
             return False
 
-        if self.field_type == "dimension_group":
+        if self.field_type == "dimension_group" and self.dimension_group is None:
             if field_name_only in self.dimension_group_names():
                 self.dimension_group = self.get_dimension_group_name(field_name_only)
                 return True
             return False
+        elif self.field_type == "dimension_group":
+            return self.alias() == field_name_only
         return self.name == field_name_only
 
     def dimension_group_names(self):
@@ -353,11 +369,11 @@ class Field(MetricsLayerBase, SQLReplacement):
         return []
 
     def get_dimension_group_name(self, field_name: str):
-        if self.type == "duration":
+        if self.type == "duration" and f"_{self.name}" in field_name:
             return field_name.replace(f"_{self.name}", "")
         if self.type == "time":
             return field_name.replace(f"{self.name}_", "")
-        return self.name
+        return None
 
     def apply_dimension_group_duration_sql(self, sql_start: str, sql_end: str, query_type: str):
         meta_lookup = {
@@ -405,11 +421,11 @@ class Field(MetricsLayerBase, SQLReplacement):
             Definitions.bigquery: {
                 "raw": lambda s, qt: s,
                 "time": lambda s, qt: f"CAST({s} as TIMESTAMP)",
-                "date": lambda s, qt: f"DATE_TRUNC(CAST({s} as DATE), DAY)",
+                "date": lambda s, qt: f"CAST(DATE_TRUNC(CAST({s} as DATE), DAY) AS {self.datatype.upper()})",
                 "week": self._week_dimension_group_time_sql,
-                "month": lambda s, qt: f"DATE_TRUNC(CAST({s} as DATE), MONTH)",
-                "quarter": lambda s, qt: f"DATE_TRUNC(CAST({s} as DATE), QUARTER)",
-                "year": lambda s, qt: f"DATE_TRUNC(CAST({s} as DATE), YEAR)",
+                "month": lambda s, qt: f"CAST(DATE_TRUNC(CAST({s} as DATE), MONTH) AS {self.datatype.upper()})",  # noqa
+                "quarter": lambda s, qt: f"CAST(DATE_TRUNC(CAST({s} as DATE), QUARTER) AS {self.datatype.upper()})",  # noqa
+                "year": lambda s, qt: f"CAST(DATE_TRUNC(CAST({s} as DATE), YEAR) AS {self.datatype.upper()})",
                 "hour_of_day": lambda s, qt: f"CAST({s} AS STRING FORMAT 'HH24')",
                 "day_of_week": lambda s, qt: f"CAST({s} AS STRING FORMAT 'DAY')",
             },
@@ -431,7 +447,10 @@ class Field(MetricsLayerBase, SQLReplacement):
             "tuesday": 6,
         }
         offset = offset_lookup[week_start_day]
-        return f"{self._week_sql_date_trunc(sql, offset, query_type)} - {offset}"
+        positioned_sql = f"{self._week_sql_date_trunc(sql, offset, query_type)} - {offset}"
+        if query_type == Definitions.bigquery:
+            positioned_sql = f"CAST({positioned_sql} AS {self.datatype.upper()})"
+        return positioned_sql
 
     @staticmethod
     def _week_sql_date_trunc(sql, offset, query_type):
@@ -447,16 +466,6 @@ class Field(MetricsLayerBase, SQLReplacement):
             return f"DATE_TRUNC(CAST({sql} as DATE) + {offset}, WEEK)"
 
     def collect_errors(self):
-        if self.field_type == "measure" and self.type == "number":
-            contains_dim = any(
-                field.field_type != "measure" for field in self.get_referenced_sql_query(strings_only=False)
-            )
-            if contains_dim:
-                error_text = (
-                    f"The field {self.name} is a measure with type number, but it's sql references "
-                    "another field that is not a measure. Please correct this reference to the right measure."
-                )
-                return [error_text]
         return []
 
     def get_referenced_sql_query(self, strings_only=True):
